﻿using System;
using LiteNetLib;
using LiteNetLib.Utils;

namespace UDPLibBench.LiteNetLib
{
	public class Client : INetEventListener
	{
		public int ReliableReceived;
		public int ReliableSent;
		public int UnreliableReceived;
		public int UnreliableSent;

        NetManager _client;
        NetDataWriter _writer;

		public Client()
		{
            _writer = new NetDataWriter();

			_client = new NetManager(this, "ConnKey");
            _client.Start();
		}

		public void SendUnreliable(string pData)
		{
            _writer.Reset();
			_writer.Put(false);
			_writer.Put(pData);

			_client.GetFirstPeer().Send(_writer, SendOptions.Unreliable);
			UnreliableSent++;
		}

		public void SendReliable(string pData)
		{
            _writer.Reset();
			_writer.Put(true);
			_writer.Put(pData);

            _client.GetFirstPeer().Send(_writer, SendOptions.ReliableOrdered);
			ReliableSent++;
		}

        public void Connect()
        {
            _client.Connect("localhost", 9050);
        }

		public void PollEvents()
		{
            _client.PollEvents();
		}

		void INetEventListener.OnNetworkError(NetEndPoint endPoint, int socketErrorCode)
		{
		}

		void INetEventListener.OnNetworkLatencyUpdate(NetPeer peer, int latency)
		{
		}

		void INetEventListener.OnNetworkReceive(NetPeer peer, NetDataReader reader)
		{
			var isReliable = reader.GetBool();
			var data = reader.GetString();

			if (isReliable)
			{
				ReliableReceived++;
			}
			else
			{
				UnreliableReceived++;
			}
		}

		void INetEventListener.OnNetworkReceiveUnconnected(NetEndPoint remoteEndPoint, NetDataReader reader, UnconnectedMessageType messageType)
		{
		}

		void INetEventListener.OnPeerConnected(NetPeer peer)
		{
		}

		void INetEventListener.OnPeerDisconnected(NetPeer peer, DisconnectInfo disconnectInfo)
		{
		}
	}
}
