﻿using System;
using LiteNetLib;
using LiteNetLib.Utils;

namespace UDPLibBench.LiteNetLib
{
    public class Server : INetEventListener
    {
        public int ReliableReceived;
        public int ReliableSent;
        public int UnreliableReceived;
        public int UnreliableSent;

        NetManager _server;
        NetDataWriter _writer;
        NetPeer _peer;

        public Server()
        {
            _server = new NetManager(this, 15, "ConnKey");
            _server.Start(9050);
        }

        public void SendUnreliable(string pData)
        {
            if (_peer == null) return;

            _writer = new NetDataWriter();
            _writer.Put(false);
            _writer.Put(pData);

            _peer.Send(_writer, SendOptions.Unreliable);
            UnreliableSent++;
        }

        public void SendReliable(string pData)
        {
            if (_peer == null) return;

			_writer = new NetDataWriter();
            _writer.Put(true);
			_writer.Put(pData);

            _peer.Send(_writer, SendOptions.ReliableOrdered);
            ReliableSent++;
        }

        public void PollEvents()
        {
            _server.PollEvents();
        }

        void INetEventListener.OnNetworkError(NetEndPoint endPoint, int socketErrorCode)
        {
        }

        void INetEventListener.OnNetworkLatencyUpdate(NetPeer peer, int latency)
        {
        }

        void INetEventListener.OnNetworkReceive(NetPeer peer, NetDataReader reader)
        {
            var _isReliable = reader.GetBool();
            var _data = reader.GetString();

            if(_isReliable)
            {
                ReliableReceived++;
            }
            else
            {
                UnreliableReceived++;
            }
        }

        void INetEventListener.OnNetworkReceiveUnconnected(NetEndPoint remoteEndPoint, NetDataReader reader, UnconnectedMessageType messageType)
        {
        }

        void INetEventListener.OnPeerConnected(NetPeer peer)
        {
            _peer = peer;
        }

        void INetEventListener.OnPeerDisconnected(NetPeer peer, DisconnectInfo disconnectInfo)
        {
        }
    }
}
