﻿using System;
using System.Threading;

namespace UDPLibBench
{
    class MainClass
    {        
        public static void Main(string[] args)
        {
            Console.WriteLine("Testing LiteNetLib...");
            Thread _serverThread = new Thread(LiteNetLibTest.StartServer);
            _serverThread.Start();
            Thread _clientThread = new Thread(LiteNetLibTest.StartClient);
            _clientThread.Start();

            //Console.WriteLine("Testing Lidgren-old...");
			//Thread _serverThread = new Thread(LidgrenOldTest.StartServer);
			//_serverThread.Start();
			//Thread _clientThread = new Thread(LidgrenOldTest.StartClient);
			//_clientThread.Start();
			
            Console.WriteLine("Processing...");
            Console.ReadKey();
        }
    }

	public class LidgrenOldTest
	{
		private const string DATA = "The quick brown fox jumps over the lazy dog";
		private static int MAX_LOOP_COUNT = 750;
		private static int UNRELIABLE_MESSAGES_PER_LOOP = 1000;
		private static int RELIABLE_MESSAGES_PER_LOOP = 350;
		private static bool CLIENT_RUNNING = true;

		public static void StartServer()
		{
            Lidgren_Old.Server _s = new Lidgren_Old.Server();

			while (CLIENT_RUNNING)
			{
				_s.PollEvents();
				Thread.Sleep(15);
			}

			Thread.Sleep(1000);
			_s.PollEvents();

			Console.WriteLine("SERVER RECEIVED -> Reliable: " + _s.ReliableReceived + ", Unreliable: " + _s.UnreliableReceived);
		}

		public static void StartClient()
		{
            Lidgren_Old.Client _c = new Lidgren_Old.Client();
			_c.Connect();

			for (int i = 0; i < MAX_LOOP_COUNT; i++)
			{
				for (int ui = 0; ui < UNRELIABLE_MESSAGES_PER_LOOP; ui++)
					_c.SendUnreliable(DATA);

				for (int ri = 0; ri < RELIABLE_MESSAGES_PER_LOOP; ri++)
					_c.SendReliable(DATA);

				_c.PollEvents();
				Thread.Sleep(15);
			}

			CLIENT_RUNNING = false;

			Console.WriteLine("CLIENT SENT -> Reliable: " + _c.ReliableSent + ", Unreliable: " + _c.UnreliableSent);
		}
	}

    public class LiteNetLibTest
    {
        private const string DATA = "The quick brown fox jumps over the lazy dog";
        private static int MAX_LOOP_COUNT = 750;
        private static int UNRELIABLE_MESSAGES_PER_LOOP = 1000;
        private static int RELIABLE_MESSAGES_PER_LOOP = 350;
        private static bool CLIENT_RUNNING = true;

        public static void StartServer()
        {
            LiteNetLib.Server _s = new LiteNetLib.Server();

            while(CLIENT_RUNNING)
            {
                _s.PollEvents();
                Thread.Sleep(15);
            }

            Thread.Sleep(1000);
            _s.PollEvents();

            Console.WriteLine("SERVER RECEIVED -> Reliable: " + _s.ReliableReceived + ", Unreliable: " + _s.UnreliableReceived);
        }

        public static void StartClient()
        {
            LiteNetLib.Client _c = new LiteNetLib.Client();
            _c.Connect();

            for (int i = 0; i < MAX_LOOP_COUNT; i++)
            {
                for (int ui = 0; ui < UNRELIABLE_MESSAGES_PER_LOOP; ui++)
                    _c.SendUnreliable(DATA);

				for (int ri = 0; ri < RELIABLE_MESSAGES_PER_LOOP; ri++)
					_c.SendReliable(DATA);
				
                _c.PollEvents();
                Thread.Sleep(15);
            }

            CLIENT_RUNNING = false;

            Console.WriteLine("CLIENT SENT -> Reliable: " + _c.ReliableSent + ", Unreliable: " + _c.UnreliableSent);
        }
    }
}
